==> scantailor-0.9.11.tar.gz: scantailor-0.9.11/translations/crashreporter_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="71"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation>Este archivo contiene el estado interno del programa cuando se colgo</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="77"/>
        <source>Dump file</source>
        <translation>archivo basura</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="105"/>
        <source>Sending ...</source>
        <translation>Enviando...</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="136"/>
        <source>Unexpected response (code %1) from dispatcher</source>
        <translation>Respuesta inesperada (codigo %1) al enviar</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="161"/>
        <source>Unexpected response from dispatcher</source>
        <translation>Respuesta inesperada al enviar</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="221"/>
        <source>Unexpected response (code %1) from the receiving side</source>
        <translation>Respuesta inesperada (codigo %1) del receptor</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="227"/>
        <source>Successfully sent</source>
        <translation>Enviado correctamente</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation>Reporte de cuelgue</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix the problem by submitting this crash report.</source>
        <translation>Scan Tailor se ha colgado.  Esto seguramente sea algun error en el programa. Tu puedes ayudarnos y arreglar el problema enviandonos este reporte de cuelgue.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation>Informacion a ser enviada</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation>Si usted tiene alguna informacion adicional, por ejemplo sabe como reproducir el cuelgue, por favor documentelo aqui en Ingles o Ruso.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation>Si usted esta dispuesto a dar asistencia a los programadores a solucionar el error, por favor denos su direccion de email.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation>Email [opcional]</translation>
    </message>
</context>
</TS>

==> scantailor_0.9.11.1.orig.tar.gz: scantailor-0.9.11.1/translations/crashreporter_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="71"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation>Este archivo contiene el estado interno del programa cuando se colgó</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="77"/>
        <source>Dump file</source>
        <translation>Archivo basura</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="105"/>
        <source>Sending ...</source>
        <translation>Enviando...</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="136"/>
        <source>Unexpected response (code %1) from dispatcher</source>
        <translation>Respuesta inesperada (codigo %1) al enviar</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="161"/>
        <source>Unexpected response from dispatcher</source>
        <translation>Respuesta inesperada al enviar</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="221"/>
        <source>Unexpected response (code %1) from the receiving side</source>
        <translation>Respuesta inesperada (codigo %1) del receptor</translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="227"/>
        <source>Successfully sent</source>
        <translation>Enviado correctamente</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation>Reporte de cuelgue</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix the problem by submitting this crash report.</source>
        <translation>Scan Tailor se ha colgado.  Esto seguramente sea algún error en el programa. Puedes ayudarnos a arreglar el problema enviandonos este reporte de cuelgue.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation>Informacion a ser enviada</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation>Si usted tiene alguna informacion adicional, por ejemplo sabe como reproducir el cuelgue, por favor documentelo aqui en Ingles o Ruso.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation>Si usted esta dispuesto a dar asistencia a los programadores a solucionar el error, por favor dénos su direccioón de email.</translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation>Email [opcional]</translation>
    </message>
</context>
</TS>
